@@ -10,7 +10,7 @@ use Scalar::Util;
 
 #use Exporter;
 
-our $VERSION = '0.329';
+our $VERSION = '0.331';
 
 =head1 NAME
 
@@ -28,7 +28,7 @@ L<Math::Quaternion>, L<Math::Vec3>
 
 =head1 SEE ALSO
 
-L<PDL>
+L<PDL> for scientific and bulk numeric data processing and display
 
 L<Math>
 
